parser

package
v0.0.0-...-df0311d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 30, 2025 License: MIT Imports: 11 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func SaveGraphToFile

func SaveGraphToFile(graph *Graph, filePath string) error

SaveGraphToFile saves a given Graph struct to a file, automatically selecting the correct format based on the output file's extension.

Types

type Graph

type Graph = axon.Graph

Graph is an alias to the generated struct for easier use in other packages.

func LoadGraphFromFile

func LoadGraphFromFile(filePath string) (*Graph, error)

LoadGraphFromFile reads a graph file, auto-detecting the format (.ax, .axb, .axd, .axc).

Jump to